@@ -70,13 +70,11 @@ def _get_module_details(
             raise error(
                 ("%s; %r is a package and cannot " + "be directly executed")
                 % (e, mod_name)
-            )
+            ) from None
     loader = spec.loader
     # use isinstance instead of `is None` to placate mypy
     if not isinstance(loader, SourceLoader):
-        raise error(
-            "%r is a namespace package and cannot be executed" % mod_name
-        )
+        raise error("%r is a namespace package and cannot be executed" % mod_name)
     try:
         code = loader.get_code(mod_name)
     except ImportError as e:
