@@ -3,15 +3,29 @@ import math
 import random
 import re
 
-from collections import OrderedDict, defaultdict
+from collections import defaultdict
 from enum import Enum
 from operator import itemgetter
 from pathlib import Path
-from pydantic import BaseModel, Field, NonNegativeFloat, NonNegativeInt, PositiveInt, StrictBool, ValidationError, model_validator
+from pydantic import (
+    BaseModel,
+    Field,
+    NonNegativeFloat,
+    NonNegativeInt,
+    PositiveInt,
+    StrictBool,
+    ValidationError,
+    model_validator,
+)
 from typing import Any, Callable, Dict, List, Optional
 
 from scalene.scalene_leak_analysis import ScaleneLeakAnalysis
-from scalene.scalene_statistics import Filename, LineNumber, ScaleneStatistics
+from scalene.scalene_statistics import (
+    Filename,
+    LineNumber,
+    ScaleneStatistics,
+    StackStats,
+)
 from scalene.scalene_analysis import ScaleneAnalysis
 
 
@@ -20,13 +34,15 @@ class GPUDevice(str, Enum):
     neuron = "Neuron"
     no_gpu = ""
 
+
 class FunctionDetail(BaseModel):
     line: str
     lineno: LineNumber
     memory_samples: List[List[Any]]
     n_avg_mb: NonNegativeFloat
     n_copy_mb_s: NonNegativeFloat
-    n_core_utilization : float = Field(..., ge=0, le=1)
+    n_core_utilization: float = Field(..., ge=0, le=1)
+    cpu_samples_list: List[float]
     n_cpu_percent_c: float = Field(..., ge=0, le=100)
     n_cpu_percent_python: float = Field(..., ge=0, le=100)
     n_gpu_avg_memory_mb: NonNegativeFloat
@@ -41,45 +57,43 @@ class FunctionDetail(BaseModel):
     n_usage_fraction: float = Field(..., ge=0, le=1)
 
     @model_validator(mode="after")
-    def check_cpu_percentages(cls, values: Any) -> Any:
+    def check_cpu_percentages(self) -> Any:
         total_cpu_usage = math.floor(
-            values.n_cpu_percent_c
-            + values.n_cpu_percent_python
-            + values.n_sys_percent
+            self.n_cpu_percent_c + self.n_cpu_percent_python + self.n_sys_percent
         )
         if total_cpu_usage > 100:
             raise ValueError(
                 f"The sum of n_cpu_percent_c, n_cpu_percent_python, and n_sys_percent must be <= 100 but is {total_cpu_usage}"
             )
-        return values
-
+        return self
 
     @model_validator(mode="after")
-    def check_gpu_memory(cls, values: Any) -> Any:
-        if values.n_gpu_avg_memory_mb > values.n_gpu_peak_memory_mb:
+    def check_gpu_memory(self) -> Any:
+        if self.n_gpu_avg_memory_mb > self.n_gpu_peak_memory_mb:
             raise ValueError(
                 "n_gpu_avg_memory_mb must be less than or equal to n_gpu_peak_memory_mb"
             )
-        return values
+        return self
 
     @model_validator(mode="after")
-    def check_cpu_memory(cls, values: Any) -> Any:
-        if values.n_avg_mb > values.n_peak_mb:
-            raise ValueError(
-                "n_avg_mb must be less than or equal to n_peak_mb"
-            )
-        return values
-    
+    def check_cpu_memory(self) -> Any:
+        if self.n_avg_mb > self.n_peak_mb:
+            raise ValueError("n_avg_mb must be less than or equal to n_peak_mb")
+        return self
+
+
 class LineDetail(FunctionDetail):
     start_outermost_loop: PositiveInt
     end_outermost_loop: PositiveInt
     start_region_line: PositiveInt
     end_region_line: PositiveInt
 
+
 class LeakInfo(BaseModel):
     likelihood: NonNegativeFloat
     velocity_mb_s: NonNegativeFloat
-    
+
+
 class FileDetail(BaseModel):
     functions: List[FunctionDetail]
     imports: List[str]
@@ -87,10 +101,13 @@ class FileDetail(BaseModel):
     lines: List[LineDetail]
     percent_cpu_time: NonNegativeFloat
 
+
 class ScaleneJSONSchema(BaseModel):
     alloc_samples: NonNegativeInt
-    args: List[str]
+    args: Optional[List[str]] = None
     elapsed_time_sec: NonNegativeFloat
+    start_time_absolute: NonNegativeFloat
+    start_time_perf: NonNegativeFloat
     entrypoint_dir: str
     filename: str
     files: Dict[str, FileDetail]
@@ -105,7 +122,7 @@ class ScaleneJSONSchema(BaseModel):
     program: str
     samples: List[List[NonNegativeFloat]]
     stacks: List[List[Any]]
-    
+
 
 class ScaleneJSON:
     @staticmethod
@@ -158,16 +175,12 @@ class ScaleneJSON:
         self.gpu = False
         self.gpu_device = ""
 
-    def compress_samples(
-        self, samples: List[Any], max_footprint: float
-    ) -> Any:
+    def compress_samples(self, samples: List[Any], max_footprint: float) -> Any:
         if len(samples) <= self.max_sparkline_samples:
             return samples
 
         new_samples = sorted(
-            random.sample(
-                list(map(tuple, samples)), self.max_sparkline_samples
-            )
+            random.sample(list(map(tuple, samples)), self.max_sparkline_samples)
         )
         return new_samples
 
@@ -190,6 +203,7 @@ class ScaleneJSON:
             return {
                 "lineno": line_no,
                 "line": line,
+                "cpu_samples_list": [],
                 "n_core_utilization": 0,
                 "n_cpu_percent_c": 0,
                 "n_cpu_percent_python": 0,
@@ -209,59 +223,58 @@ class ScaleneJSON:
             }
 
         # Prepare output values.
-        n_cpu_samples_c = stats.cpu_samples_c[fname][line_no]
+        n_cpu_samples_c = stats.cpu_stats.cpu_samples_c[fname][line_no]
         # Correct for negative CPU sample counts. This can happen
         # because of floating point inaccuracies, since we perform
         # subtraction to compute it.
         n_cpu_samples_c = max(0, n_cpu_samples_c)
-        n_cpu_samples_python = stats.cpu_samples_python[fname][line_no]
-        n_gpu_samples = stats.gpu_samples[fname][line_no]
-        n_gpu_mem_samples = stats.gpu_mem_samples[fname][line_no]
+        n_cpu_samples_python = stats.cpu_stats.cpu_samples_python[fname][line_no]
+        n_gpu_samples = stats.gpu_stats.gpu_samples[fname][line_no]
+        n_gpu_mem_samples = stats.gpu_stats.gpu_mem_samples[fname][line_no]
 
         # Compute percentages of CPU time.
-        if stats.total_cpu_samples:
-            n_cpu_percent_c = n_cpu_samples_c * 100 / stats.total_cpu_samples
+        if stats.cpu_stats.total_cpu_samples:
+            n_cpu_percent_c = n_cpu_samples_c * 100 / stats.cpu_stats.total_cpu_samples
             n_cpu_percent_python = (
-                n_cpu_samples_python * 100 / stats.total_cpu_samples
+                n_cpu_samples_python * 100 / stats.cpu_stats.total_cpu_samples
             )
         else:
             n_cpu_percent_c = 0
             n_cpu_percent_python = 0
 
         if True:
-            if stats.n_gpu_samples[fname][line_no]:
+            if stats.gpu_stats.n_gpu_samples[fname][line_no]:
                 n_gpu_percent = (
-                    n_gpu_samples * 100 / stats.n_gpu_samples[fname][line_no]
+                    n_gpu_samples * 100 / stats.gpu_stats.n_gpu_samples[fname][line_no]
                 )  # total_gpu_samples
             else:
                 n_gpu_percent = 0
 
         # Now, memory stats.
         # Total volume of memory allocated.
-        n_malloc_mb = stats.memory_malloc_samples[fname][line_no]
+        n_malloc_mb = stats.memory_stats.memory_malloc_samples[fname][line_no]
         # Number of distinct allocation calls (those from the same line are counted as 1).
-        n_mallocs = stats.memory_malloc_count[fname][line_no]
+        n_mallocs = stats.memory_stats.memory_malloc_count[fname][line_no]
         # Total volume of memory allocated by Python (not native code).
-        n_python_malloc_mb = stats.memory_python_samples[fname][line_no]
+        n_python_malloc_mb = stats.memory_stats.memory_python_samples[fname][line_no]
 
         n_usage_fraction = (
             0
-            if not stats.total_memory_malloc_samples
-            else n_malloc_mb / stats.total_memory_malloc_samples
-        )
-        n_python_fraction = (
-            0 if not n_malloc_mb else n_python_malloc_mb / n_malloc_mb
+            if not stats.memory_stats.total_memory_malloc_samples
+            else n_malloc_mb / stats.memory_stats.total_memory_malloc_samples
         )
+        n_python_fraction = 0 if not n_malloc_mb else n_python_malloc_mb / n_malloc_mb
 
         # Average memory consumed by this line.
         n_avg_mb = (
-            stats.memory_aggregate_footprint[fname][line_no]
+            stats.memory_stats.memory_aggregate_footprint[fname][line_no]
             if n_mallocs == 0
-            else stats.memory_aggregate_footprint[fname][line_no] / n_mallocs
+            else stats.memory_stats.memory_aggregate_footprint[fname][line_no]
+            / n_mallocs
         )
 
         # Peak memory consumed by this line.
-        n_peak_mb = stats.memory_max_footprint[fname][line_no]
+        n_peak_mb = stats.memory_stats.memory_max_footprint[fname][line_no]
 
         # Force the reporting of average to be no more than peak.
         # In principle, this should never happen, but...
@@ -272,30 +285,33 @@ class ScaleneJSON:
         n_cpu_percent = n_cpu_percent_c + n_cpu_percent_python
 
         # Adjust CPU time by utilization.
-        mean_cpu_util = stats.cpu_utilization[fname][line_no].mean()
-        mean_core_util = stats.core_utilization[fname][line_no].mean()
+        mean_cpu_util = stats.cpu_stats.cpu_utilization[fname][line_no].mean()
+        mean_core_util = stats.cpu_stats.core_utilization[fname][line_no].mean()
         n_sys_percent = n_cpu_percent * (1.0 - mean_cpu_util)
         n_cpu_percent_python *= mean_cpu_util
         n_cpu_percent_c *= mean_cpu_util
         del mean_cpu_util
 
-        n_copy_b = stats.memcpy_samples[fname][line_no]
+        n_copy_b = stats.memory_stats.memcpy_samples[fname][line_no]
         if stats.elapsed_time:
             n_copy_mb_s = n_copy_b / (1024 * 1024 * stats.elapsed_time)
         else:
             n_copy_mb_s = 0
 
-        stats.per_line_footprint_samples[fname][line_no] = (
+        stats.memory_stats.per_line_footprint_samples[fname][line_no] = (
             self.compress_samples(
-                stats.per_line_footprint_samples[fname][line_no],
-                stats.max_footprint,
+                stats.memory_stats.per_line_footprint_samples[fname][line_no],
+                stats.memory_stats.max_footprint,
             )
         )
 
         payload = {
             "line": line,
             "lineno": line_no,
-            "memory_samples": stats.per_line_footprint_samples[fname][line_no],
+            "memory_samples": stats.memory_stats.per_line_footprint_samples[fname][
+                line_no
+            ],
+            "cpu_samples_list": stats.cpu_stats.cpu_samples_list[fname][line_no],
             "n_avg_mb": n_avg_mb,
             "n_copy_mb_s": n_copy_mb_s,
             "n_core_utilization": mean_core_util,
@@ -338,21 +354,21 @@ class ScaleneJSON:
             stats.merge_stats(python_alias_dir)
         # If we've collected any samples, dump them.
         if (
-            not stats.total_cpu_samples
-            and not stats.total_memory_malloc_samples
-            and not stats.total_memory_free_samples
-            and not stats.total_gpu_samples
+            not stats.cpu_stats.total_cpu_samples
+            and not stats.memory_stats.total_memory_malloc_samples
+            and not stats.memory_stats.total_memory_free_samples
+            and not stats.gpu_stats.n_gpu_samples[program]
         ):
             # Nothing to output.
             return {}
         # Collect all instrumented filenames.
         all_instrumented_files: List[Filename] = list(
             set(
-                list(stats.cpu_samples_python.keys())
-                + list(stats.cpu_samples_c.keys())
-                + list(stats.memory_free_samples.keys())
-                + list(stats.memory_malloc_samples.keys())
-                + list(stats.gpu_samples.keys())
+                list(stats.cpu_stats.cpu_samples_python.keys())
+                + list(stats.cpu_stats.cpu_samples_c.keys())
+                + list(stats.memory_stats.memory_free_samples.keys())
+                + list(stats.memory_stats.memory_malloc_samples.keys())
+                + list(stats.gpu_stats.gpu_samples.keys())
             )
         )
         if not all_instrumented_files:
@@ -360,19 +376,20 @@ class ScaleneJSON:
             return {}
         growth_rate = 0.0
         if profile_memory:
-            stats.memory_footprint_samples = self.compress_samples(
-                stats.memory_footprint_samples, stats.max_footprint
+            stats.memory_stats.memory_footprint_samples = self.compress_samples(
+                stats.memory_stats.memory_footprint_samples,
+                stats.memory_stats.max_footprint,
             )
 
             # Compute growth rate (slope), between 0 and 1.
-            if stats.allocation_velocity[1] > 0:
+            if stats.memory_stats.allocation_velocity[1] > 0:
                 growth_rate = (
                     100.0
-                    * stats.allocation_velocity[0]
-                    / stats.allocation_velocity[1]
+                    * stats.memory_stats.allocation_velocity[0]
+                    / stats.memory_stats.allocation_velocity[1]
                 )
         else:
-            stats.memory_footprint_samples = []
+            stats.memory_stats.memory_footprint_samples = []
 
         # Adjust the program name if it was a Jupyter cell.
         result = re.match(r"_ipython-input-([0-9]+)-.*", program)
@@ -380,43 +397,57 @@ class ScaleneJSON:
             program = Filename("[" + result.group(1) + "]")
 
         # Process the stacks to normalize by total number of CPU samples.
-        for stk in stats.stacks.keys():
-            (count, python_time, c_time, cpu_samples) = stats.stacks[stk]
-            stats.stacks[stk] = (
-                count,
-                python_time / stats.total_cpu_samples,
-                c_time / stats.total_cpu_samples,
-                cpu_samples / stats.total_cpu_samples,
+        for stk in stats.stacks:
+            stack_stats = stats.stacks[stk]
+            stats.stacks[stk] = StackStats(
+                stack_stats.count,
+                stack_stats.python_time / stats.cpu_stats.total_cpu_samples,
+                stack_stats.c_time / stats.cpu_stats.total_cpu_samples,
+                stack_stats.cpu_samples / stats.cpu_stats.total_cpu_samples,
             )
 
         # Convert stacks into a representation suitable for JSON dumping.
         stks = []
-        for stk in stats.stacks.keys():
+        for stk in stats.stacks:
             this_stk: List[str] = []
-            this_stk.extend(stk)
-            stks.append((this_stk, stats.stacks[stk]))
+            this_stk.extend(str(frame) for frame in stk)
+            stack_stats = stats.stacks[stk]
+            # Convert StackStats to a dictionary
+            stack_stats_dict = {
+                "count": stack_stats.count,
+                "python_time": stack_stats.python_time,
+                "c_time": stack_stats.c_time,
+                "cpu_samples": stack_stats.cpu_samples,
+            }
+            stks.append((this_stk, stack_stats_dict))
 
         output: Dict[str, Any] = {
             "program": program,
             "entrypoint_dir": entrypoint_dir,
             "args": program_args,
             "filename": program_path,
-            "alloc_samples": stats.alloc_samples,
+            "alloc_samples": stats.memory_stats.alloc_samples,
             "elapsed_time_sec": stats.elapsed_time,
+            "start_time_absolute": stats.start_time_absolute,
+            "start_time_perf": stats.start_time_perf,
             "growth_rate": growth_rate,
-            "max_footprint_mb": stats.max_footprint,
-            "max_footprint_python_fraction": stats.max_footprint_python_fraction,
+            "max_footprint_mb": stats.memory_stats.max_footprint,
+            "max_footprint_python_fraction": stats.memory_stats.max_footprint_python_fraction,
             "max_footprint_fname": (
-                stats.max_footprint_loc[0] if stats.max_footprint_loc else None
+                stats.memory_stats.max_footprint_loc[0]
+                if stats.memory_stats.max_footprint_loc
+                else None
             ),
             "max_footprint_lineno": (
-                stats.max_footprint_loc[1] if stats.max_footprint_loc else None
+                stats.memory_stats.max_footprint_loc[1]
+                if stats.memory_stats.max_footprint_loc
+                else None
             ),
             "files": {},
             "gpu": self.gpu,
             "gpu_device": self.gpu_device,
             "memory": profile_memory,
-            "samples": stats.memory_footprint_samples,
+            "samples": stats.memory_stats.memory_footprint_samples,
             "stacks": stks,
         }
 
@@ -425,13 +456,13 @@ class ScaleneJSON:
         # Sort in descending order of CPU cycles, and then ascending order by filename
         for fname in sorted(
             all_instrumented_files,
-            key=lambda f: (-(stats.cpu_samples[f]), f),
+            key=lambda f: (-(stats.cpu_stats.cpu_samples[f]), f),
         ):
             fname = Filename(fname)
             try:
                 percent_cpu_time = (
                     100
-                    * stats.cpu_samples[fname]
+                    * stats.cpu_stats.cpu_samples[fname]
                     / stats.elapsed_time
                     # 100 * stats.cpu_samples[fname] / stats.total_cpu_samples
                 )
@@ -440,7 +471,8 @@ class ScaleneJSON:
 
             # Ignore files responsible for less than some percent of execution time and fewer than a threshold # of mallocs.
             if (
-                stats.malloc_samples[fname] < self.malloc_threshold
+                sum(stats.memory_stats.memory_malloc_samples[fname].values())
+                < self.malloc_threshold
                 and percent_cpu_time < self.cpu_percent_threshold
             ):
                 continue
@@ -471,16 +503,18 @@ class ScaleneJSON:
             # Leak analysis
             # First, compute AVERAGE memory consumption.
             avg_mallocs: Dict[LineNumber, float] = defaultdict(float)
-            for line_no in stats.bytei_map[fname]:
-                n_malloc_mb = stats.memory_aggregate_footprint[fname][line_no]
-                count = stats.memory_malloc_count[fname][line_no]
+            for line_no in stats.memory_stats.memory_malloc_count[fname]:
+                n_malloc_mb = stats.memory_stats.memory_aggregate_footprint[fname][
+                    line_no
+                ]
+                count = stats.memory_stats.memory_malloc_count[fname][line_no]
                 if count:
                     avg_mallocs[line_no] = n_malloc_mb / count
                 else:
                     # Setting to n_malloc_mb addresses the edge case where this allocation is the last line executed.
                     avg_mallocs[line_no] = n_malloc_mb
 
-            avg_mallocs = OrderedDict(
+            avg_mallocs = dict(
                 sorted(avg_mallocs.items(), key=itemgetter(1), reverse=True)
             )
 
@@ -502,11 +536,13 @@ class ScaleneJSON:
                 }
 
             # Print header.
-            if not stats.total_cpu_samples:
+            if not stats.cpu_stats.total_cpu_samples:
                 percent_cpu_time = 0
             else:
                 percent_cpu_time = (
-                    100 * stats.cpu_samples[fname] / stats.total_cpu_samples
+                    100
+                    * stats.cpu_stats.cpu_samples[fname]
+                    / stats.cpu_stats.total_cpu_samples
                 )
 
             # Print out the the profile for the source, line by line.
@@ -548,15 +584,9 @@ class ScaleneJSON:
                     force_print=False,
                 )
                 if profile_line:
-                    profile_line["start_region_line"] = enclosing_regions[
-                        lineno
-                    ][0]
-                    profile_line["end_region_line"] = enclosing_regions[
-                        lineno
-                    ][1]
-                    profile_line["start_outermost_loop"] = outer_loop[lineno][
-                        0
-                    ]
+                    profile_line["start_region_line"] = enclosing_regions[lineno][0]
+                    profile_line["end_region_line"] = enclosing_regions[lineno][1]
+                    profile_line["start_outermost_loop"] = outer_loop[lineno][0]
                     profile_line["end_outermost_loop"] = outer_loop[lineno][1]
 
                     try:
@@ -564,7 +594,7 @@ class ScaleneJSON:
                     except ValidationError as e:
                         print("Warning: JSON failed validation:")
                         print(e)
-                    
+
                     # When reduced-profile set, only output if the payload for the line is non-zero.
                     if reduced_profile:
                         profile_line_copy = copy.copy(profile_line)
@@ -578,11 +608,11 @@ class ScaleneJSON:
             # Check CPU samples and memory samples.
             print_fn_summary = False
             all_samples = set()
-            all_samples |= set(fn_stats.cpu_samples_python.keys())
-            all_samples |= set(fn_stats.cpu_samples_c.keys())
-            all_samples |= set(fn_stats.memory_malloc_samples.keys())
-            all_samples |= set(fn_stats.memory_free_samples.keys())
-            all_samples |= set(fn_stats.gpu_samples.keys())
+            all_samples |= set(fn_stats.cpu_stats.cpu_samples_python.keys())
+            all_samples |= set(fn_stats.cpu_stats.cpu_samples_c.keys())
+            all_samples |= set(fn_stats.memory_stats.memory_malloc_samples.keys())
+            all_samples |= set(fn_stats.memory_stats.memory_free_samples.keys())
+            all_samples |= set(fn_stats.gpu_stats.gpu_samples.keys())
             print_fn_summary = any(fn != fname for fn in all_samples)
             output["files"][fname_print]["functions"] = []
             if print_fn_summary:
@@ -608,9 +638,7 @@ class ScaleneJSON:
                     if profile_line:
                         # Fix the line number to point to the first line of the function.
                         profile_line["lineno"] = stats.firstline_map[fn_name]
-                        output["files"][fname_print]["functions"].append(
-                            profile_line
-                        )
+                        output["files"][fname_print]["functions"].append(profile_line)
 
         # Validate the schema
         try:
