@@ -115,9 +115,7 @@ class ScaleneOutput:
 
         # Finally, print results.
         n_cpu_percent_c_str: str = (
-            ""
-            if obj["n_cpu_percent_c"] < 1
-            else f"{obj['n_cpu_percent_c']:5.0f}%"
+            "" if obj["n_cpu_percent_c"] < 1 else f"{obj['n_cpu_percent_c']:5.0f}%"
         )
 
         n_gpu_percent_str: str = (
@@ -162,9 +160,7 @@ class ScaleneOutput:
             # Randomly downsample to ScaleneOutput.max_sparkline_len_line.
             if len(samples) > ScaleneOutput.max_sparkline_len_line:
                 random_samples = sorted(
-                    random.sample(
-                        samples, ScaleneOutput.max_sparkline_len_line
-                    )
+                    random.sample(samples, ScaleneOutput.max_sparkline_len_line)
                 )
             else:
                 random_samples = samples
@@ -175,7 +171,7 @@ class ScaleneOutput:
 
             if random_samples:
                 _, _, spark_str = sparkline.generate(
-                    sparkline_samples, 0, stats.max_footprint
+                    sparkline_samples, 0, stats.memory_stats.max_footprint
                 )
 
             # Red highlight
@@ -183,6 +179,7 @@ class ScaleneOutput:
             ncpcs: Any = ""
             nufs: Any = ""
             ngpus: Any = ""
+            nsys: Any = ""
 
             n_usage_fraction_str: str = (
                 ""
@@ -195,28 +192,24 @@ class ScaleneOutput:
                     obj["n_cpu_percent_c"]
                     + obj["n_cpu_percent_python"]
                     + obj["n_gpu_percent"]
+                    + obj["n_sys_percent"]
                 )
                 >= self.highlight_percentage
             ):
-                ncpps = Text.assemble(
-                    (n_cpu_percent_python_str, self.highlight_color)
-                )
-                ncpcs = Text.assemble(
-                    (n_cpu_percent_c_str, self.highlight_color)
-                )
+                ncpps = Text.assemble((n_cpu_percent_python_str, self.highlight_color))
+                ncpcs = Text.assemble((n_cpu_percent_c_str, self.highlight_color))
                 nufs = Text.assemble(
                     (spark_str + n_usage_fraction_str, self.highlight_color)
                 )
-                ngpus = Text.assemble(
-                    (n_gpu_percent_str, self.highlight_color)
-                )
+                ngpus = Text.assemble((n_gpu_percent_str, self.highlight_color))
             else:
                 ncpps = n_cpu_percent_python_str
                 ncpcs = n_cpu_percent_c_str
                 ngpus = n_gpu_percent_str
                 nufs = spark_str + n_usage_fraction_str
+                nsys = sys_str
 
-            if reduced_profile and not ncpps + ncpcs + nufs + ngpus:
+            if reduced_profile and not ncpps + ncpcs + nufs + ngpus + nsys:
                 return False
 
             n_python_fraction_str: str = (
@@ -225,9 +218,7 @@ class ScaleneOutput:
                 else f"{(obj['n_python_fraction'] * 100):4.0f}%"
             )
             n_copy_mb_s_str: str = (
-                ""
-                if obj["n_copy_mb_s"] < 0.5
-                else f"{obj['n_copy_mb_s']:6.0f}"
+                "" if obj["n_copy_mb_s"] < 0.5 else f"{obj['n_copy_mb_s']:6.0f}"
             )
 
             if self.gpu:
@@ -262,23 +253,21 @@ class ScaleneOutput:
                 obj["n_cpu_percent_c"]
                 + obj["n_cpu_percent_python"]
                 + obj["n_gpu_percent"]
+                + obj["n_sys_percent"]
             ) >= self.highlight_percentage:
-                ncpps = Text.assemble(
-                    (n_cpu_percent_python_str, self.highlight_color)
-                )
-                ncpcs = Text.assemble(
-                    (n_cpu_percent_c_str, self.highlight_color)
-                )
-                ngpus = Text.assemble(
-                    (n_gpu_percent_str, self.highlight_color)
-                )
+                ncpps = Text.assemble((n_cpu_percent_python_str, self.highlight_color))
+                ncpcs = Text.assemble((n_cpu_percent_c_str, self.highlight_color))
+                ngpus = Text.assemble((n_gpu_percent_str, self.highlight_color))
+                nsys = Text.assemble((sys_str, self.highlight_color))
             else:
                 ncpps = n_cpu_percent_python_str
                 ncpcs = n_cpu_percent_c_str
                 ngpus = n_gpu_percent_str
+                nsys = sys_str
 
-            if reduced_profile and not ncpps + ncpcs + ngpus:
+            if reduced_profile and not ncpps + ncpcs + ngpus + nsys:
                 return False
+
             if self.gpu:
                 tbl.add_row(
                     print_line_no,
@@ -319,19 +308,19 @@ class ScaleneOutput:
             stats.merge_stats(python_alias_dir)
         # If we've collected any samples, dump them.
         if (
-            not stats.total_cpu_samples
-            and not stats.total_memory_malloc_samples
-            and not stats.total_memory_free_samples
+            not stats.cpu_stats.total_cpu_samples
+            and not stats.memory_stats.total_memory_malloc_samples
+            and not stats.memory_stats.total_memory_free_samples
         ):
             # Nothing to output.
             return False
         # Collect all instrumented filenames.
         all_instrumented_files: List[Filename] = list(
             set(
-                list(stats.cpu_samples_python.keys())
-                + list(stats.cpu_samples_c.keys())
-                + list(stats.memory_free_samples.keys())
-                + list(stats.memory_malloc_samples.keys())
+                list(stats.cpu_stats.cpu_samples_python.keys())
+                + list(stats.cpu_stats.cpu_samples_c.keys())
+                + list(stats.memory_stats.memory_free_samples.keys())
+                + list(stats.memory_stats.memory_malloc_samples.keys())
             )
         )
         if not all_instrumented_files:
@@ -340,14 +329,12 @@ class ScaleneOutput:
         mem_usage_line: Union[Text, str] = ""
         growth_rate = 0.0
         if profile_memory:
-            samples = stats.memory_footprint_samples
+            samples = stats.memory_stats.memory_footprint_samples
             if len(samples) > 0:
                 # Randomly downsample samples
                 if len(samples) > ScaleneOutput.max_sparkline_len_file:
                     random_samples = sorted(
-                        random.sample(
-                            samples, ScaleneOutput.max_sparkline_len_file
-                        )
+                        random.sample(samples, ScaleneOutput.max_sparkline_len_file)
                     )
                 else:
                     random_samples = samples
@@ -356,24 +343,24 @@ class ScaleneOutput:
                 _, _, spark_str = sparkline.generate(
                     sparkline_samples[: ScaleneOutput.max_sparkline_len_file],
                     0,
-                    stats.max_footprint,
+                    stats.memory_stats.max_footprint,
                 )
                 # Compute growth rate (slope), between 0 and 1.
-                if stats.allocation_velocity[1] > 0:
+                if stats.memory_stats.allocation_velocity[1] > 0:
                     growth_rate = (
                         100.0
-                        * stats.allocation_velocity[0]
-                        / stats.allocation_velocity[1]
+                        * stats.memory_stats.allocation_velocity[0]
+                        / stats.memory_stats.allocation_velocity[1]
                     )
                 mem_usage_line = Text.assemble(
                     "Memory usage: ",
                     ((spark_str, self.memory_color)),
                     (
-                        f" (max: {ScaleneJSON.memory_consumed_str(stats.max_footprint)}, growth rate: {growth_rate:3.0f}%)\n"
+                        f" (max: {ScaleneJSON.memory_consumed_str(stats.memory_stats.max_footprint)}, growth rate: {growth_rate:3.0f}%)\n"
                     ),
                 )
 
-        null = tempfile.TemporaryFile(mode="w+")
+        null = open(os.devnull, "w")  # noqa: SIM115
 
         console = Console(
             width=column_width,
@@ -387,19 +374,21 @@ class ScaleneOutput:
         # Sort in descending order of CPU cycles, and then ascending order by filename
         for fname in sorted(
             all_instrumented_files,
-            key=lambda f: (-(stats.cpu_samples[f]), f),
+            key=lambda f: (-(stats.cpu_stats.cpu_samples[f]), f),
         ):
             fname = Filename(fname)
             try:
                 percent_cpu_time = (
-                    100 * stats.cpu_samples[fname] / stats.total_cpu_samples
+                    100
+                    * stats.cpu_stats.cpu_samples[fname]
+                    / stats.cpu_stats.total_cpu_samples
                 )
             except ZeroDivisionError:
                 percent_cpu_time = 0
 
             # Ignore files responsible for less than some percent of execution time and fewer than a threshold # of mallocs.
             if (
-                stats.malloc_samples[fname] < ScaleneJSON.malloc_threshold
+                stats.memory_stats.malloc_samples[fname] < ScaleneJSON.malloc_threshold
                 and percent_cpu_time < ScaleneJSON.cpu_percent_threshold
             ):
                 continue
@@ -426,8 +415,12 @@ class ScaleneOutput:
 
             # Print header.
             percent_cpu_time = (
-                (100 * stats.cpu_samples[fname] / stats.total_cpu_samples)
-                if stats.total_cpu_samples
+                (
+                    100
+                    * stats.cpu_stats.cpu_samples[fname]
+                    / stats.cpu_stats.total_cpu_samples
+                )
+                if stats.cpu_stats.total_cpu_samples
                 else 0
             )
 
@@ -493,9 +486,7 @@ class ScaleneOutput:
                     width=6,
                 )
                 tbl.add_column(
-                    Markdown(
-                        "–––––––––––  \n_timeline_/%", style=self.memory_color
-                    ),
+                    Markdown("–––––––––––  \n_timeline_/%", style=self.memory_color),
                     style=self.memory_color,
                     no_wrap=True,
                     width=15,
@@ -546,9 +537,7 @@ class ScaleneOutput:
             )
             formatted_lines = [
                 SyntaxLine(segments)
-                for segments in capture_console.render_lines(
-                    syntax_highlighted
-                )
+                for segments in capture_console.render_lines(syntax_highlighted)
             ]
             for line_no, line in enumerate(formatted_lines, start=1):
                 old_did_print = did_print
@@ -577,10 +566,10 @@ class ScaleneOutput:
             print_fn_summary = False
             # Check CPU samples and memory samples.
             all_samples = set()
-            all_samples |= set(fn_stats.cpu_samples_python.keys())
-            all_samples |= set(fn_stats.cpu_samples_c.keys())
-            all_samples |= set(fn_stats.memory_malloc_samples.keys())
-            all_samples |= set(fn_stats.memory_free_samples.keys())
+            all_samples |= set(fn_stats.cpu_stats.cpu_samples_python.keys())
+            all_samples |= set(fn_stats.cpu_stats.cpu_samples_c.keys())
+            all_samples |= set(fn_stats.memory_stats.memory_malloc_samples.keys())
+            all_samples |= set(fn_stats.memory_stats.memory_free_samples.keys())
             for fn_name in all_samples:
                 if fn_name == fname:
                     continue
@@ -606,7 +595,7 @@ class ScaleneOutput:
                     tbl.add_row("", "", "", "", txt)
 
                 for fn_name in sorted(
-                    fn_stats.cpu_samples_python,
+                    fn_stats.cpu_stats.cpu_samples_python,
                     key=lambda k: stats.firstline_map[k],
                 ):
                     if fn_name == fname:
@@ -640,12 +629,14 @@ class ScaleneOutput:
             # Compute AVERAGE memory consumption.
             avg_mallocs: Dict[LineNumber, float] = defaultdict(float)
             for line_no in stats.bytei_map[fname]:
-                n_malloc_mb = stats.memory_aggregate_footprint[fname][line_no]
-                if count := stats.memory_malloc_count[fname][line_no]:
-                    avg_mallocs[line_no] = n_malloc_mb / count
+                n_malloc_mb = stats.memory_stats.memory_aggregate_footprint[fname][
+                    line_no
+                ]
+                if count := stats.memory_stats.memory_malloc_count[fname][line_no]:
+                    avg_mallocs[LineNumber(line_no)] = n_malloc_mb / count
                 else:
                     # Setting to n_malloc_mb addresses the edge case where this allocation is the last line executed.
-                    avg_mallocs[line_no] = n_malloc_mb
+                    avg_mallocs[LineNumber(line_no)] = n_malloc_mb
 
             avg_mallocs = OrderedDict(
                 sorted(avg_mallocs.items(), key=itemgetter(1), reverse=True)
@@ -654,9 +645,9 @@ class ScaleneOutput:
             # Compute (really, aggregate) PEAK memory consumption.
             peak_mallocs: Dict[LineNumber, float] = defaultdict(float)
             for line_no in stats.bytei_map[fname]:
-                peak_mallocs[line_no] = stats.memory_max_footprint[fname][
-                    line_no
-                ]
+                peak_mallocs[LineNumber(line_no)] = (
+                    stats.memory_stats.memory_max_footprint[fname][line_no]
+                )
 
             peak_mallocs = OrderedDict(
                 sorted(peak_mallocs.items(), key=itemgetter(1), reverse=True)
