@@ -6,6 +6,8 @@ import signal
 import struct
 import subprocess
 import sys
+import warnings
+
 from typing import Dict
 import scalene
 
@@ -14,25 +16,26 @@ class ScalenePreload:
     @staticmethod
     def get_preload_environ(args: argparse.Namespace) -> Dict[str, str]:
         env = {
-            "SCALENE_ALLOCATION_SAMPLING_WINDOW": str(
-                args.allocation_sampling_window
-            )
+            "SCALENE_ALLOCATION_SAMPLING_WINDOW": str(args.allocation_sampling_window)
         }
 
         # Disable JITting in PyTorch and JAX to improve profiling,
         # unless the environment variables are already set.
         # JAX_DISABLE_JIT: https://jax.readthedocs.io/en/latest/debugging/flags.html#id1
         # PYTORCH_JIT: https://pytorch.org/docs/stable/jit.html#disable-jit-for-debugging
-        jit_flags = [ ('JAX_DISABLE_JIT', '1'), # truthy => disable JIT
-                      ('PYTORCH_JIT', '0') ]    # falsy => disable JIT
-       
+        jit_flags = [
+            ("JAX_DISABLE_JIT", "1"),  # truthy => disable JIT
+            ("PYTORCH_JIT", "0"),
+        ]  # falsy => disable JIT
+
         try:
             # If we are running on Neuron, we don't disable the JITs
             # because it leads to unacceptably high overheads.
             from scalene.scalene_neuron import ScaleneNeuron
+
             accelerator = ScaleneNeuron()
             on_neuron = accelerator.has_gpu()
-        except:
+        except Exception:
             on_neuron = False
         if not on_neuron:
             for name, val in jit_flags:
@@ -54,34 +57,34 @@ class ScalenePreload:
 
         elif sys.platform == "linux":
             if args.memory:
- 
+
                 library_path = scalene.__path__[0]
-                
+
                 # NOTE: you can't use escape sequences inside an f-string pre-3.12 either
-                
+
                 # We use this function in two places:
                 # 1. in `setup_preload`
                 # 2. when calling into `redirect_python`
-                if 'LD_LIBRARY_PATH' not in os.environ:
-                    env['LD_LIBRARY_PATH'] = library_path
-                elif library_path not in os.environ['LD_LIBRARY_PATH']:
-                    env['LD_LIBRARY_PATH'] = f'{library_path}:{os.environ["LD_LIBRARY_PATH"]}'
+                if "LD_LIBRARY_PATH" not in os.environ:
+                    env["LD_LIBRARY_PATH"] = library_path
+                elif library_path not in os.environ["LD_LIBRARY_PATH"]:
+                    env["LD_LIBRARY_PATH"] = (
+                        f'{library_path}:{os.environ["LD_LIBRARY_PATH"]}'
+                    )
 
-                new_ld_preload = 'libscalene.so'
-                if "LD_PRELOAD" in os.environ and new_ld_preload not in os.environ["LD_PRELOAD"]:
-                    old_ld_preload = os.environ["LD_PRELOAD"]
-                    env["LD_PRELOAD"] = new_ld_preload + ":" + old_ld_preload
-                else:
+                new_ld_preload = "libscalene.so"
+                if "LD_PRELOAD" not in os.environ:
                     env["LD_PRELOAD"] = new_ld_preload
+                elif new_ld_preload not in os.environ["LD_PRELOAD"].split(":"):
+                    env["LD_PRELOAD"] = f'{new_ld_preload}:{os.environ["LD_PRELOAD"]}'
                 # Disable command-line specified PYTHONMALLOC.
                 if "PYTHONMALLOC" in os.environ:
                     # Since the environment dict is updated
                     # with a `.update` call, we need to make sure
-                    # that there's some value for PYTHONMALLOC in 
-                    # what we return if we want to squash an anomalous 
+                    # that there's some value for PYTHONMALLOC in
+                    # what we return if we want to squash an anomalous
                     # value
-                    env['PYTHONMALLOC'] = 'default'
-                    
+                    env["PYTHONMALLOC"] = "default"
 
         elif sys.platform == "win32":
             # Force no memory profiling on Windows for now.
@@ -104,16 +107,16 @@ class ScalenePreload:
             or struct.calcsize("P") != 8
         ):
             args.memory = False
-            print(
+            warnings.warn(
                 "Scalene warning: currently only 64-bit x86-64 and ARM platforms are supported for memory and copy profiling."
             )
 
         with contextlib.suppress(Exception):
             from IPython import get_ipython
 
-            if get_ipython():
-                sys.exit = Scalene.clean_exit  # type: ignore
-                sys._exit = Scalene.clean_exit  # type: ignore
+            if get_ipython():  # type: ignore[no-untyped-call,unused-ignore]
+                sys.exit = scalene.Scalene.clean_exit  # type: ignore
+                sys._exit = scalene.Scalene.clean_exit  # type: ignore
 
         # Start a subprocess with the required environment variables,
         # which may include preloading libscalene
