@@ -10,11 +10,11 @@ from time import perf_counter
 from pprint import PrettyPrinter
 
 
-printable = [('string', (1, 2), [3, 4], {5: 6, 7: 8})] * 100_000
+printable = [("string", (1, 2), [3, 4], {5: 6, 7: 8})] * 100_000
 p = PrettyPrinter()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
     start_p = perf_counter()
     for i in range(7):
