@@ -7,23 +7,23 @@ from sympy.core.cache import clear_cache
 
 
 def bench_expand():
-    x, y, z = symbols('x y z')
+    x, y, z = symbols("x y z")
     expand((1 + x + y + z) ** 20)
 
 
 def bench_integrate():
-    x, y = symbols('x y')
+    x, y = symbols("x y")
     f = (1 / tan(x)) ** 10
     return integrate(f, x)
 
 
 def bench_sum():
-    x, i = symbols('x i')
-    summation(x ** i / i, (i, 1, 400))
+    x, i = symbols("x i")
+    summation(x**i / i, (i, 1, 400))
 
 
 def bench_str():
-    x, y, z = symbols('x y z')
+    x, y, z = symbols("x y z")
     str(expand((x + 2 * y + 3 * z) ** 30))
 
 
@@ -37,7 +37,7 @@ def bench_sympy(loops, func):
 
         t0 = timer()
         func()
-        dt += (timer() - t0)
+        dt += timer() - t0
 
     return dt
 
@@ -54,6 +54,7 @@ if __name__ == "__main__":
     # sympy-expand
 
     import gc
+
     gc.disable()
 
     start_p = time.perf_counter()
@@ -61,6 +62,6 @@ if __name__ == "__main__":
         # Don't benchmark clear_cache(), exclude it of the benchmark
         clear_cache()
         bench_expand()
-    
+
     stop_p = time.perf_counter()
     print("Time elapsed: ", stop_p - start_p)
