@@ -1,5 +1,6 @@
 import numpy as np
 
+
 class A:
 
     def __init__(self, n):
@@ -7,5 +8,6 @@ class A:
         self.lst = [1] * n
         print(n)
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     a = A(50_000_000)
