@@ -6,10 +6,11 @@ import os
 import pytest
 from scalene.scalene_profiler import Scalene
 
+
 # Test function to cover the before_fork method
 def test_before_fork(monkeypatch):
     # Setup: Mock the stop_signal_queues method
-    monkeypatch.setattr(Scalene, 'stop_signal_queues', lambda: None)
+    monkeypatch.setattr(Scalene, "stop_signal_queues", lambda: None)
 
     # Test: Call the before_fork method
     Scalene.before_fork()
@@ -18,6 +19,7 @@ def test_before_fork(monkeypatch):
     # In a real test, we would need to check the actual state or use a more sophisticated mock
     # No assertions are needed here as we are just testing that the method can be called without error
 
+
 # Ensure that the test is only run when called by pytest and not during import
 if __name__ == "__main__":
     pytest.main([__file__])
