@@ -7,20 +7,26 @@ from scalene.scalene_profiler import Scalene
 from scalene.scalene_arguments import ScaleneArguments
 from unittest.mock import patch
 
+
 # Mocking the ScaleneParseArgs.parse_args method to return specific arguments
 @pytest.fixture
 def mock_parse_args():
-    with patch('scalene.scalene_profiler.ScaleneParseArgs.parse_args') as mock:
+    with patch("scalene.scalene_profiler.ScaleneParseArgs.parse_args") as mock:
         mock.return_value = (ScaleneArguments(), [])
         yield mock
 
+
 # Mocking the Scalene.set_initialized and Scalene.run_profiler methods
 @pytest.fixture
 def mock_scalene_methods():
-    with patch('scalene.scalene_profiler.Scalene.set_initialized') as mock_initialized, \
-         patch('scalene.scalene_profiler.Scalene.run_profiler') as mock_run_profiler:
+    with patch(
+        "scalene.scalene_profiler.Scalene.set_initialized"
+    ) as mock_initialized, patch(
+        "scalene.scalene_profiler.Scalene.run_profiler"
+    ) as mock_run_profiler:
         yield mock_initialized, mock_run_profiler
 
+
 # Test function to cover lines 1836-1841
 def test_main_execution(mock_parse_args, mock_scalene_methods):
     Scalene.main()
