@@ -7,12 +7,13 @@ import signal
 import pytest
 from scalene.scalene_profiler import Scalene
 
+
 @pytest.fixture
 def scalene_setup_and_teardown():
     # Setup code
     Scalene.start = lambda: None
     Scalene.__orig_kill = os.kill
-    Scalene.__signals = type('Signals', (), {'start_profiling_signal': signal.SIGCONT})
+    Scalene.__signals = type("Signals", (), {"start_profiling_signal": signal.SIGCONT})
     Scalene.child_pids = set()
     # Create a child process and add its PID to the set
     pid = os.fork()
@@ -29,6 +30,7 @@ def scalene_setup_and_teardown():
         Scalene.child_pids.remove(pid)
     Scalene.child_pids.clear()
 
+
 def test_start_signal_handler(scalene_setup_and_teardown):
     # Test that the signal handler sends the start_profiling_signal to child processes
     Scalene.start_signal_handler(None, None)
