@@ -5,10 +5,14 @@
 import pytest
 from scalene.scalene_parseargs import ScaleneParseArgs
 
+
 class StopJupyterExecution(Exception):
     pass
 
+
 def test_clean_exit(monkeypatch):
-    monkeypatch.setattr("scalene.scalene_parseargs.StopJupyterExecution", StopJupyterExecution)
+    monkeypatch.setattr(
+        "scalene.scalene_parseargs.StopJupyterExecution", StopJupyterExecution
+    )
     with pytest.raises(StopJupyterExecution):
         ScaleneParseArgs.clean_exit()
