@@ -7,17 +7,18 @@ import pytest
 import tempfile
 from scalene.scalene_profiler import Scalene
 
+
 # Test function to improve coverage for Scalene.exit_handler
 def test_exit_handler_cleanup(monkeypatch):
     # Setup a temporary directory and patch Scalene to use it
     temp_dir = tempfile.TemporaryDirectory()
-    monkeypatch.setattr(Scalene, '_Scalene__python_alias_dir', temp_dir, raising=False)
-    monkeypatch.setattr(Scalene, '_Scalene__pid', 0)  # Ensure the cleanup code runs
+    monkeypatch.setattr(Scalene, "_Scalene__python_alias_dir", temp_dir, raising=False)
+    monkeypatch.setattr(Scalene, "_Scalene__pid", 0)  # Ensure the cleanup code runs
 
     # Create a temporary file to simulate the malloc lock file
     malloc_lock_file = f"/tmp/scalene-malloc-lock{os.getpid()}"
-    with open(malloc_lock_file, 'w') as f:
-        f.write('')
+    with open(malloc_lock_file, "w") as f:
+        f.write("")
 
     # Ensure the malloc lock file exists before calling the exit handler
     assert os.path.exists(malloc_lock_file)
